From 80ef15b98170dbaef39757ad9cd6a5f75a1a4902 Mon Sep 17 00:00:00 2001
From: Saul Wold <sgw@linux.intel.com>
Date: Thu, 9 May 2019 12:32:06 -0700
Subject: [PATCH] build-tools: Convert wrsroot -> sysadmin

This also changes the group wrs_protected to sys_protected
to de-brand the user and group names.

Change-Id: I887464a20fc17d66529caea03be2b445156f9426
Story: 2004716
Task: 30925
Signed-off-by: Saul Wold <sgw@linux.intel.com>
---
 build-tools/build_guest/rootfs-setup.sh | 8 ++++----
 build-tools/build_iso/anaconda-ks.cfg   | 2 +-
 build-tools/build_iso/ks.cfg            | 2 +-
 build-tools/build_minimal_iso/README    | 8 ++++----
 4 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/build-tools/build_iso/anaconda-ks.cfg b/build-tools/build_iso/anaconda-ks.cfg
index 0f325b03..24d8d488 100644
--- a/build-tools/build_iso/anaconda-ks.cfg
+++ b/build-tools/build_iso/anaconda-ks.cfg
@@ -22,7 +22,7 @@ network --device=lo  --hostname=localhost.localdomain
 rootpw --lock
 # System timezone
 timezone America/New_York --isUtc
-user --groups=wheel --name=wrsroot --password=$6$c3gaCcJlh.rp//Yx$/mIjNNoUDS1qZldBL29YSJdsA9ttPA/nXN1CPsIcCmionXC22APT3IoRSd9j5dPiZoviDdQf7YxLsOYdieOQr/ --iscrypted --gecos="wrsroot"
+user --groups=wheel --name=sysadmin --password=$6$Mazui8NX.w6C5I$UWNzOnui.vb3qOT3Qyw0I6hMLW0G02KfQGcCZTXdVv9GDZLUXHJVeGEN1/RAe.EOgz2cLkFkVaS8pvwBTFG1j/ --iscrypted --gecos="sysadmin"
 # System bootloader configuration
 bootloader --location=mbr --boot-drive=sda
 autopart --type=lvm
diff --git a/build-tools/build_iso/ks.cfg b/build-tools/build_iso/ks.cfg
index 75877ade..7613111c 100644
--- a/build-tools/build_iso/ks.cfg
+++ b/build-tools/build_iso/ks.cfg
@@ -13,7 +13,7 @@ network --device=lo  --hostname=localhost.localdomain
 
 rootpw --lock
 timezone America/New_York --isUtc
-user --groups=wheel --name=wrsroot --password=$6$c3gaCcJlh.rp//Yx$/mIjNNoUDS1qZldBL29YSJdsA9ttPA/nXN1CPsIcCmionXC22APT3IoRSd9j5dPiZoviDdQf7YxLsOYdieOQr/ --iscrypted --gecos="wrsroot"
+user --groups=wheel --name=sysadmin --password=$6$c3gaCcJlh.rp//Yx$/mIjNNoUDS1qZldBL29YSJdsA9ttPA/nXN1CPsIcCmionXC22APT3IoRSd9j5dPiZoviDdQf7YxLsOYdieOQr/ --iscrypted --gecos="sysadmin"
 
 # System bootloader configuration
 #bootloader --location=mbr --boot-drive=sda
diff --git a/build-tools/build_minimal_iso/README b/build-tools/build_minimal_iso/README
index 1259094d..70cba6c5 100644
--- a/build-tools/build_minimal_iso/README
+++ b/build-tools/build_minimal_iso/README
@@ -94,13 +94,13 @@ Power the system on with the DVD inserted.  A system install will take place
 (takes approximately 2 minutes).  The system will then report an error and
 ask you if you wish to report a bug, debug, or quit.  Hit control-alt-F2 to
 switch to a terminal window.  Enter the following commands to change to the
-installed system root, and create a (wrsroot) with sudo access:
+installed system root, and create a (sysadmin) with sudo access:
 
 cd /mnt/sysimage
 chroot .
 groupadd -r wrs
-groupadd -f -g 345 wrs_protected
-useradd -m -g wrs -G root,wrs_protected,wheel -d /home/wrsroot -p cBglipPpsKwBQ -s /bin/sh wrsroot
+groupadd -f -g 345 sys_protected
+useradd -m -g wrs -G root,sys_protected,wheel -d /home/sysadmin -p cBglipPpsKwBQ -s /bin/sh sysadmin
 exit
 
 Change back to the main window with control-alt-F1.
@@ -108,5 +108,5 @@ Hit 3 <enter> (the "Quit" option).  The system will reboot (make sure you eject
 the DVD or use your BIOS to boot from hard disk rather than DVD; the installer
 will re-run if the DVD boots again).
 
-You can log into the system as user "wrsroot" with password "wrsroot".
+You can log into the system as user "sysadmin" with password "sysadmin".
diff --git a/build-tools/build_guest/rootfs-setup.sh b/build-tools/build_guest/rootfs-setup.sh
index d46cac29..5af65666 100755
--- a/build-tools/build_guest/rootfs-setup.sh
+++ b/build-tools/build_guest/rootfs-setup.sh
@@ -12,12 +12,12 @@ fi
 ln -s $(ls /boot/vmlinuz-*.x86_64 | head -1) /boot/vmlinuz
 ln -s $(ls /boot/initramfs-*.x86_64.img | head -1) /boot/initramfs.img
 
 # Setup root and wrsroot users
 usermod -p $(openssl passwd -1 root) root
-useradd -p $(openssl passwd -1 wrsroot) wrsroot
+useradd -p $(openssl passwd -1 sysadmin) sysadmin
 
-# Enable SUDO access for wrsroot
-echo "wrsroot ALL=(ALL) NOPASSWD: ALL" >> /etc/sudoers
+# Enable SUDO access for sysadmin
+echo "sysadmin ALL=(ALL) NOPASSWD: ALL" >> /etc/sudoers
 
 # Enable remote root login to permit automated tools to run privileged commands
 sed -i 's%^#\(PermitRootLogin \)%\1%' /etc/ssh/sshd_config
@@ -12,12 +12,12 @@ fi
 ln -s $(ls /boot/initramfs-*.x86_64.img | head -1) /boot/initramfs.img
 
-# Setup root and wrsroot users
+# Setup root and sysadmin users
 usermod -p $(openssl passwd -1 root) root